# eric7.Plugins.PluginAbout

This plugin shows the About dialogs.

### Global Attributes

__header__
error

### Classes

AboutPlugin | Class implementing the About plugin.

### Functions

None

## AboutPlugin

Class implementing the About plugin.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

AboutPlugin | Constructor
__about | Private slot to handle the About dialog.
__aboutQt | Private slot to handle the About Qt dialog.
__initActions | Private method to initialize the actions.
__initMenu | Private method to add the actions to the right menu.
activate | Public method to activate this plugin.
deactivate | Public method to deactivate this plugin.

### Static Methods

None

#### AboutPlugin (Constructor)

AboutPlugin(ui)

Constructor

ui (UserInterface)
  reference to the user interface object

#### AboutPlugin.__about

__about()

Private slot to handle the About dialog.

#### AboutPlugin.__aboutQt

__aboutQt()

Private slot to handle the About Qt dialog.

#### AboutPlugin.__initActions

__initActions()

Private method to initialize the actions.

#### AboutPlugin.__initMenu

__initMenu()

Private method to add the actions to the right menu.

#### AboutPlugin.activate

activate()

Public method to activate this plugin.

Return:
  tuple of None and activation status

Return Type:
  bool

#### AboutPlugin.deactivate

deactivate()

Public method to deactivate this plugin.

Up